@@ -115,12 +115,12 @@ def delete_ldap_group(groupName):
         l.delete_s(dn)
 
 
-def _insert_jos_xgroups(db, name, description):
+def _insert_jos_xgroups(db, name, description, grouptype):
         sql =  "INSERT INTO jos_xgroups ( `cn`, `description`, `published`, `type`, `public_desc`, `private_desc`, `restrict_msg`, "
         sql += "`join_policy`, `discussion_email_autosubscribe`, `logo`, `overview_type`, `overview_content`, `plugins`, `created`,"
         sql += "`created_by`, `params`) " 
         sql += "VALUES (" + '%s,'*15 + "%s );" 
-        data = (name, description, 0, 1, '', '', '', 1, 0, '', None, None, None, datetime.datetime.now(), None, None)
+        data = (name, description, 0, int(grouptype), '', '', '', 1, 0, '', None, None, None, datetime.datetime.now(), None, None)
 
         gidNumber = db.query_lastrowid(sql, data)
 
